import imageio 
import os 
import pygame
import random

class pygame_screen_recorder:
    def __init__(self, outfile):
        self.outfile = outfile
        self.file_count = 0
        # make a temp folder with a uuid
        self.temp_folder = f'.__temp_gif{random.randint(0, 1000000)}'
        os.mkdir(self.temp_folder)

    def click(self, screen):
        fn = f"{self.temp_folder}/{self.file_count}.png"
        pygame.image.save(screen, fn)
        self.file_count += 1

    def save(self):
        files = os.listdir(self.temp_folder)
        files = sorted(files, key=lambda x: int(os.path.splitext(x)[0]))
        print(files)
        images = []
        for filename in files:
            images.append(imageio.imread(f'./{self.temp_folder}/{filename}'))
        imageio.mimsave(self.outfile, images)

    def __del__(self):
        # delete all files in temp folder
        files = os.listdir(self.temp_folder)
        for filename in files:
            os.remove(f'./{self.temp_folder}/{filename}')
        os.rmdir(self.temp_folder)




from setuptools import setup, find_packages
 
classifiers = [
  'Intended Audience :: Education',
  'Operating System :: Microsoft :: Windows :: Windows 10',
  'License :: OSI Approved :: MIT License',
  'Programming Language :: Python :: 3'
]
 
setup(
  name='pygame_screen_recorder',
  version='1.0',
  description='Util for taking screenshots and recording videos of pygame games',
  long_description=open('README.md').read(),
  url='',  
  author='Sol Zilberman',
  author_email='sol.zilberman@gmail.com',
  license='MIT', 
  classifiers=classifiers,
  keywords='pygame', 
  packages=find_packages(),
  install_requires=['pygame', 'imageio'] 
)